asr.magnetic\_anisotropy
========================

.. automodule:: asr.magnetic_anisotropy

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_spin_axis
   .. autofunction:: get_spin_index
   .. autofunction:: spin_axis
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   